pub struct PairwiseStepPlan<'a> { /* private fields */ }Expand description
Read-only lowering data for one pairwise contraction step.
Examples
use tenferro_einsum::{ContractionTree, Subscripts};
let subs = Subscripts::new(&[&[0, 1], &[1, 2]], &[0, 2]);
let tree = ContractionTree::from_pairs(&subs, &[&[2, 3], &[3, 4]], &[(0, 1)]).unwrap();
let step = tree.step_plan(0).unwrap();
assert_eq!(step.gemm().contracted_modes(), &[1]);Implementations
Sourceimpl<'a> PairwiseStepPlan<'a>
impl<'a> PairwiseStepPlan<'a>
Sourcepub fn lhs_diag(&self) -> Option<DiagPlan<'a>>
pub fn lhs_diag(&self) -> Option<DiagPlan<'a>>
Return the left operand diagonal extraction plan, if any.
Examples
use tenferro_einsum::{ContractionTree, Subscripts};
let subs = Subscripts::new(&[&[0, 1], &[1, 2]], &[0, 2]);
let tree = ContractionTree::from_pairs(&subs, &[&[2, 3], &[3, 4]], &[(0, 1)]).unwrap();
assert!(tree.step_plan(0).unwrap().lhs_diag().is_none());Sourcepub fn rhs_diag(&self) -> Option<DiagPlan<'a>>
pub fn rhs_diag(&self) -> Option<DiagPlan<'a>>
Return the right operand diagonal extraction plan, if any.
Examples
use tenferro_einsum::{ContractionTree, Subscripts};
let subs = Subscripts::new(&[&[0, 1], &[1, 2]], &[0, 2]);
let tree = ContractionTree::from_pairs(&subs, &[&[2, 3], &[3, 4]], &[(0, 1)]).unwrap();
assert!(tree.step_plan(0).unwrap().rhs_diag().is_none());Sourcepub fn lhs_reduce(&self) -> Option<ReducePlan<'a>>
pub fn lhs_reduce(&self) -> Option<ReducePlan<'a>>
Return the left operand pre-reduction plan, if any.
Examples
use tenferro_einsum::{ContractionTree, Subscripts};
let subs = Subscripts::new(&[&[0, 1], &[1, 2]], &[2]);
let tree = ContractionTree::from_pairs(&subs, &[&[2, 3], &[3, 4]], &[(0, 1)]).unwrap();
let reduce = tree.step_plan(0).unwrap().lhs_reduce().unwrap();
assert_eq!(reduce.kept_subs(), &[1]);Sourcepub fn rhs_reduce(&self) -> Option<ReducePlan<'a>>
pub fn rhs_reduce(&self) -> Option<ReducePlan<'a>>
Return the right operand pre-reduction plan, if any.
Examples
use tenferro_einsum::{ContractionTree, Subscripts};
let subs = Subscripts::new(&[&[0, 1], &[1, 2]], &[0]);
let tree = ContractionTree::from_pairs(&subs, &[&[2, 3], &[3, 4]], &[(0, 1)]).unwrap();
let reduce = tree.step_plan(0).unwrap().rhs_reduce().unwrap();
assert_eq!(reduce.kept_subs(), &[1]);Sourcepub fn gemm(&self) -> GemmPlan<'a>
pub fn gemm(&self) -> GemmPlan<'a>
Return the GEMM decomposition for this pairwise step.
Examples
use tenferro_einsum::{ContractionTree, Subscripts};
let subs = Subscripts::new(&[&[0, 1], &[1, 2]], &[0, 2]);
let tree = ContractionTree::from_pairs(&subs, &[&[2, 3], &[3, 4]], &[(0, 1)]).unwrap();
let gemm = tree.step_plan(0).unwrap().gemm();
assert_eq!(gemm.output_gemm_shape(), &[2, 4]);Trait Implementations
Sourceimpl<'a> Clone for PairwiseStepPlan<'a>
impl<'a> Clone for PairwiseStepPlan<'a>
Sourcefn clone(&self) -> PairwiseStepPlan<'a>
fn clone(&self) -> PairwiseStepPlan<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for PairwiseStepPlan<'a>
impl<'a> Debug for PairwiseStepPlan<'a>
impl<'a> Copy for PairwiseStepPlan<'a>