pub struct EinsumNotation {
pub inputs: Vec<Vec<EinsumAxis>>,
pub output: Vec<EinsumAxis>,
}Expand description
Rank-unresolved einsum notation.
This is the programmatic counterpart of string notation such as
"...ij,...jk->...ik". Resolve it through an einsum operation, after input
ranks are known; EinsumSubscripts remains the rank-resolved runtime form.
Examples
use tenferro_einsum::{EinsumAxis, EinsumNotation};
let notation = EinsumNotation::new(&[&[EinsumAxis::Ellipsis]], &[]);
assert_eq!(notation.input_count(), 1);Fields
inputs: Vec<Vec<EinsumAxis>>Axis tokens for each input tensor.
output: Vec<EinsumAxis>Axis tokens for the output tensor.
Implementations
Sourceimpl EinsumNotation
impl EinsumNotation
Sourcepub fn new(inputs: &[&[EinsumAxis]], output: &[EinsumAxis]) -> Self
pub fn new(inputs: &[&[EinsumAxis]], output: &[EinsumAxis]) -> Self
Create rank-unresolved notation from axis-token arrays.
Examples
use tenferro_einsum::{EinsumAxis, EinsumNotation};
let notation = EinsumNotation::new(
&[&[EinsumAxis::Ellipsis, EinsumAxis::Label(0)], &[EinsumAxis::Ellipsis, EinsumAxis::Label(0)]],
&[EinsumAxis::Ellipsis],
);
assert_eq!(notation.input_count(), 2);Sourcepub fn input_count(&self) -> usize
pub fn input_count(&self) -> usize
Number of input operands described by this notation.
Examples
use tenferro_einsum::{EinsumAxis, EinsumNotation};
let notation = EinsumNotation::new(&[&[EinsumAxis::Ellipsis]], &[]);
assert_eq!(notation.input_count(), 1);Trait Implementations
Sourceimpl Clone for EinsumNotation
impl Clone for EinsumNotation
Sourcefn clone(&self) -> EinsumNotation
fn clone(&self) -> EinsumNotation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EinsumNotation
impl Debug for EinsumNotation
impl Eq for EinsumNotation
Sourceimpl Hash for EinsumNotation
impl Hash for EinsumNotation
Sourceimpl PartialEq for EinsumNotation
impl PartialEq for EinsumNotation
Sourcefn eq(&self, other: &EinsumNotation) -> bool
fn eq(&self, other: &EinsumNotation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EinsumNotation