TypedTensorEinsumIntoExt

Trait TypedTensorEinsumIntoExt 

pub trait TypedTensorEinsumIntoExt<T: TensorScalar> {
    // Required methods
    fn einsum_into<'out, B, O>(
        &self,
        subscripts: &str,
        backend: &mut B,
        out: O,
    ) -> Result<()>
       where B: TensorBackend,
             O: Into<TypedTensorWrite<'out, T>>;
    fn einsum_into_subscripts<'out, B, O>(
        &self,
        subscripts: &EinsumSubscripts,
        backend: &mut B,
        out: O,
    ) -> Result<()>
       where B: TensorBackend,
             O: Into<TypedTensorWrite<'out, T>>;
}
Backend-explicit preallocated-output einsum methods for typed concrete tensors.

Required Methods

fn einsum_into<'out, B, O>( &self, subscripts: &str, backend: &mut B, out: O, ) -> Result<()>
where B: TensorBackend, O: Into<TypedTensorWrite<'out, T>>,

Execute an einsum from string notation into caller-provided typed output.

Errors

Returns Error::InvalidSubscripts for malformed notation, Error::Validation with a shape, rank, or dtype payload when inputs or output do not match, or Error::Tensor for a typed backend failure.

fn einsum_into_subscripts<'out, B, O>( &self, subscripts: &EinsumSubscripts, backend: &mut B, out: O, ) -> Result<()>
where B: TensorBackend, O: Into<TypedTensorWrite<'out, T>>,

Execute an einsum from parsed integer-label subscripts into caller-provided typed output.

Errors

Returns Error::Validation with a shape, rank, or dtype payload when inputs or output do not match, or Error::Tensor for a typed backend failure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<T: TensorScalar> TypedTensorEinsumIntoExt<T> for [&TypedTensor<T>]

Source

fn einsum_into<'out, B, O>( &self, subscripts: &str, backend: &mut B, out: O, ) -> Result<()>
where B: TensorBackend, O: Into<TypedTensorWrite<'out, T>>,

Source

fn einsum_into_subscripts<'out, B, O>( &self, subscripts: &EinsumSubscripts, backend: &mut B, out: O, ) -> Result<()>
where B: TensorBackend, O: Into<TypedTensorWrite<'out, T>>,

Source

impl<T: TensorScalar, const N: usize> TypedTensorEinsumIntoExt<T> for [&TypedTensor<T>; N]

Source

fn einsum_into<'out, B, O>( &self, subscripts: &str, backend: &mut B, out: O, ) -> Result<()>
where B: TensorBackend, O: Into<TypedTensorWrite<'out, T>>,

Source

fn einsum_into_subscripts<'out, B, O>( &self, subscripts: &EinsumSubscripts, backend: &mut B, out: O, ) -> Result<()>
where B: TensorBackend, O: Into<TypedTensorWrite<'out, T>>,

Implementors