pub enum Error {
ShapeMismatch {
expected: Vec<usize>,
got: Vec<usize>,
},
InvalidArgument(String),
}Expand description
Errors produced while parsing, planning, or lowering einsum expressions.
Examples
use tenferro_einsum::Error;
let err = Error::ShapeMismatch {
expected: vec![2, 3],
got: vec![2, 4],
};
assert!(err.to_string().contains("shape mismatch"));Variants
ShapeMismatch
Tensor shapes are incompatible for an einsum expression.
Fields
InvalidArgument(String)
An invalid einsum argument was provided.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn to_tensor_error(&self, op: &'static str) -> Error
pub fn to_tensor_error(&self, op: &'static str) -> Error
Convert this einsum error into a tensor backend failure.
Examples
use tenferro_einsum::Error;
use tenferro_tensor::Error as TensorError;
let err = Error::InvalidArgument("bad subscripts".into())
.to_tensor_error("einsum_extension");
assert!(matches!(
err,
TensorError::BackendFailure {
op: "einsum_extension",
..
}
));Trait Implementations
Sourceimpl Error for Error
impl Error for Error
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
impl Eq for Error
impl StructuralPartialEq for Error